#' @details 
#' `fiery` is a lightweight and flexible framework for web servers build on top of
#' the [httpuv][httpuv::httpuv-package] package. The framework is largely 
#' event-based, letting the developer attach handlers to life-cycle events as
#' well as defining and triggering their own events. This approach to
#' development is common in JavaScript, but might feel foreign to R developers.
#' Thankfully it is a rather simple concept that should be easy to gradually
#' begin to use to greater and greater effect.
#' @keywords internal
'_PACKAGE'

## usethis namespace: start
#' @import rlang
## usethis namespace: end
NULL
